#!/usr/bin/env python3

# This amulet test deploys the bundles.yaml file in this directory.

import os
import unittest
import yaml
import amulet
import sys
#import urllib

# Lots of prereqs on this charm (eg: java), so give it a large timeout
seconds_to_wait = 1000


class BundleTest(unittest.TestCase):
    """ Create a class for testing the charm in the unit test framework. """
    @classmethod
    def setUpClass(cls):
        """ Set up an amulet deployment using the bundle. """
        d = amulet.Deployment()

        local_path = os.path.join(os.path.dirname(__file__), 'local.yaml')
        with open(local_path, "r") as fd:
            config = yaml.safe_load(fd)

        url = config.get('ib').get('ib_url')
        print('Using URL  %s' % url)
        # Test if a IB url for the repository is defined
        if not url:
            print("You need to define a url for the IB packages repository.\n"
                  "Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)

        pkg = config.get('ib').get('ib_package')
        print('Using IB package %s' % pkg)
        if not pkg:
            print("You need to define a package name for IBM IB.\n"
                  "Edit local.yaml or tests/00-setup and run it again.")
            sys.exit(1)

        bundle_path = os.path.join(os.path.dirname(__file__), 'bundles.yaml')
        with open(bundle_path, 'r') as bundle_file:
            contents = yaml.safe_load(bundle_file)
            d.load(contents)

        # Software doesn't actually install until you accept the license
        d.configure('ibm-ib', {'accept-ibm-ib-license': True, 'url': url, 'package': pkg})
        d.setup(seconds_to_wait)
        d.sentry.wait(seconds_to_wait)
        cls.d = d

    def test_deployed(self):
        """ Test to see if the bundle deployed successfully. """
        self.assertTrue(self.d.deployed)

if __name__ == '__main__':
    unittest.main()
